from distutils.core import setup
setup(
    name='svdc',
    packages=['svdc'],
    version='1.0.5',
    license='MIT',
    # Give a short description about your library
    description='Stefano Valentino: Test Dependency Confusion vulnerability',
    author='Stefano Valentino',                   # Type in your name
    author_email='stefano.valentino@outlook.com',      # Type in your E-Mail
    # url = 'https://github.com/user/reponame',   # Provide either the link to your github or to your website
    # download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Education',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
)
